pub struct Segment {
    pub segment_type: SegmentType,
    pub range: Range<u64>,
}
Describes the location of a chunk in the file, as well as indicating if it contains data or is a hole

Fields

segment_type: SegmentType

Marks this segment as either containing a hole, or containing data

range: Range<u64>

the (half-open) range of bytes in the file covered by this segment

Implementations

Returns true if the provided offset is within the range of bytes this segment specifies

Returns true if this segment is a Hole

Returns true if this segment contains data

The starting position of this segment

The number of bytes in this segment