Struct drill_press::Segment
source · [−]pub struct Segment {
pub segment_type: SegmentType,
pub range: Range<u64>,
}Expand description
Describes the location of a chunk in the file, as well as indicating if it contains data or is a hole
Fields
segment_type: SegmentTypeMarks this segment as either containing a hole, or containing data
range: Range<u64>the (half-open) range of bytes in the file covered by this segment
Implementations
sourceimpl Segment
impl Segment